#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""FAL command for a OneDrive cloud service."""

import libfal.falcmd as falcmd
from libfal.util import get_proxy, NoProxy
from fal_info import ReqTypes
from fal_info import Results
import pal_info

from pkgaddon.onedrive_config import (BUSINESS_AUTH_SERVER_URL,)


RESULT_NAME = "result"
FAILED_RESULT = "Failed"


class FalOneDrive(falcmd.FalCmd):
    """FAL OneDrive command implementation class."""

    def __get_proxy(self, url):

        try:
            return get_proxy(url)
        except NoProxy:
            pass

        return ""

    def __apply_handler(self, entry):
        """Handle apply request and set entry to result."""

        try:
            proxy_info = self.__get_proxy(BUSINESS_AUTH_SERVER_URL)

            if proxy_info:
                entry.get().append_child(proxy_info)

            return self.send_entry(entry, pal_info.PAL_ONEDRIVE_PATH)
        except:
            self.exception("apply failed")
            entry.set_result(Results.APPLY_ERROR)

        return entry

    def __init__(self, option=None):
        """Constructor."""

        falcmd.FalCmd.__init__(self, option=option)

        pass_handler = \
            lambda entry: self.send_entry(entry, pal_info.PAL_ONEDRIVE_PATH)

        self.set_handler(ReqTypes.GET, pass_handler)
        self.set_handler(ReqTypes.APPLY, self.__apply_handler)
        self.set_handler(ReqTypes.QUERY, pass_handler)
        self.set_handler(ReqTypes.DOWNLOAD, pass_handler)

#
# Main
#

if __name__ == "__main__":
    FalOneDrive(option=falcmd.FalCmdOption()).handle_request()
