#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

from ...baseset import BaseSetBool, BaseSetText, BaseSetValidateConvText
from fal_validinfo import (Numeric, RemotePortNumber,
    HttpMethod, DownloadInterval, AmazonS3StorageClass)


class SetAmazonS3(BaseSetBool):
    VALIDATE = "Boolean"
    PATH = "shareservice/amazons3"
    ATTR = "amazons3"


class SetAmazonS3AccessKey(BaseSetText):
    VALIDATE = "NoCheck"
    VALIDATE_OPTION = {"max_length": "255"}
    PATH = "shareservice/amazons3/accesskey"


class SetAmazonS3SecretKey(BaseSetText):
    VALIDATE = "NoCheck"
    VALIDATE_OPTION = {"max_length": "255"}
    PATH = "shareservice/amazons3/secretkey"


class SetAmazonS3Bucket(BaseSetText):
    VALIDATE = "NoCheck"
    VALIDATE_OPTION = {"max_length": "63", "min_length": "3"}
    PATH = "shareservice/amazons3/bucket"


class SetAmazonS3HttpMethod(BaseSetText):
    VALIDATE = HttpMethod.VALIDATOR
    PATH = "shareservice/amazons3/httpmethod"
    DEFAULT = HttpMethod.INITIAL


class SetAmazonS3StorageClass(BaseSetText):
    VALIDATE = AmazonS3StorageClass.VALIDATOR
    PATH = "shareservice/amazons3/storageclass"
    DEFAULT = AmazonS3StorageClass.INITIAL


class SetAmazonS3DownloadInterval(BaseSetValidateConvText):
    VALIDATE = DownloadInterval.VALIDATOR
    PATH = "shareservice/amazons3/downloadinterval"
    DEFAULT = DownloadInterval.INITIAL

    def hour_to_second(self, hour):
        try:
            return str(int(hour) * 3600)
        except:
            return hour

    CONV = hour_to_second


class SetAmazonS3EndPoint(BaseSetText):
    VALIDATE = "NoCheck"
    VALIDATE_OPTION = {"max_length": "255"}
    PATH = "shareservice/amazons3/endpoint"


class SetAmazonS3Port(BaseSetText):
    VALIDATE = RemotePortNumber.VALIDATOR
    PATH = "shareservice/amazons3/port"


class SetAmazonS3UploadMaxFileSize(BaseSetText):
    VALIDATE = Numeric.VALIDATOR
    PATH = "shareservice/amazons3/uploadmaxfilesize"
    VALIDATE_OPTION = {"max": str(5 * 1024 * 1024)}
    DEFAULT = str(10 * 1024)


class SetAmazonS3Mpupload(BaseSetBool):
    VALIDATE = "Boolean"
    PATH = "shareservice/amazons3/mpupload"
    DEFAULT = "true"


class SetCloudn(BaseSetBool):
    VALIDATE = "Boolean"
    PATH = "shareservice/cloudn.tmp"
    ATTR = "cloudn"
 

class SetCloudnAccessKey(BaseSetText):
    VALIDATE = "NoCheck"
    VALIDATE_OPTION = {"max_length": "255"}
    PATH = "shareservice/cloudn.tmp/accesskey"


class SetCloudnSecretKey(BaseSetText):
    VALIDATE = "NoCheck"
    VALIDATE_OPTION = {"max_length": "255"}
    PATH = "shareservice/cloudn.tmp/secretkey"


class SetCloudnBucket(BaseSetText):
    VALIDATE = "NoCheck"
    VALIDATE_OPTION = {"max_length": "63", "min_length": "3"}
    PATH = "shareservice/cloudn.tmp/bucket"


class SetCloudnHttpMethod(BaseSetText):
    VALIDATE = HttpMethod.VALIDATOR
    PATH = "shareservice/cloudn.tmp/httpmethod"
    DEFAULT = HttpMethod.INITIAL


class SetCloudnStorageClass(BaseSetText):
    VALIDATE = AmazonS3StorageClass.VALIDATOR
    PATH = "shareservice/cloudn.tmp/storageclass"
    DEFAULT = AmazonS3StorageClass.INITIAL


class SetCloudnDownloadInterval(BaseSetValidateConvText):
    VALIDATE = DownloadInterval.VALIDATOR
    PATH = "shareservice/cloudn.tmp/downloadinterval"
    DEFAULT = DownloadInterval.INITIAL

    def hour_to_second(self, hour):
        try:
            return str(int(hour) * 3600)
        except:
            return hour

    CONV = hour_to_second


class SetCloudnEndPoint(BaseSetText):
    VALIDATE = "NoCheck"
    VALIDATE_OPTION = {"max_length": "255"}
    PATH = "shareservice/cloudn.tmp/endpoint"
    DEFAULT = "str.cloudn-service.com"


class SetCloudnPort(BaseSetText):
    VALIDATE = RemotePortNumber.VALIDATOR
    PATH = "shareservice/cloudn.tmp/port"


class SetCloudnUploadMaxFileSize(BaseSetText):
    VALIDATE = Numeric.VALIDATOR
    PATH = "shareservice/cloudn.tmp/uploadmaxfilesize"
    VALIDATE_OPTION = {"max": str(5 * 1024 * 1024)}
    DEFAULT = str(10 * 1024)


class SetCloudnMpupload(BaseSetBool):
    VALIDATE = "Boolean"
    PATH = "shareservice/cloudn.tmp/mpupload"
    DEFAULT = "true"


class SetDropbox(BaseSetBool):
    VALIDATE = "Boolean"
    PATH = "shareservice/dropbox"


class SetAzure(BaseSetBool):
    VALIDATE = "Boolean"
    PATH = "shareservice/azure"


class SetAzureAccountName(BaseSetText):
    VALIDATE = "NoCheck"
    VALIDATE_OPTION = {"max_length": "255"}
    PATH = "shareservice/azure/accountname"


class SetAzureAccessKey(BaseSetText):
    VALIDATE = "NoCheck"
    VALIDATE_OPTION = {"max_length": "255"}
    PATH = "shareservice/azure/accesskey"


class SetAzureContainer(BaseSetText):
    VALIDATE = "NoCheck"
    VALIDATE_OPTION = {"max_length": "63", "min_length": "3"}
    PATH = "shareservice/azure/container"


class SetAzureHttpMethod(BaseSetText):
    VALIDATE = HttpMethod.VALIDATOR
    PATH = "shareservice/azure/httpmethod"
    DEFAULT = HttpMethod.INITIAL


class SetAzureDownloadInterval(BaseSetValidateConvText):
    VALIDATE = DownloadInterval.VALIDATOR
    PATH = "shareservice/azure/downloadinterval"
    DEFAULT = DownloadInterval.INITIAL

    def hour_to_second(self, hour):
        try:
            return str(int(hour) * 3600)
        except:
            return hour

    CONV = hour_to_second
