#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

import os
import sys
from iobase.xmldata import XmlConfNode
from fal_info import FAL_SHARES_PATH, FAL_SERVICECTRL_PATH

# debpkg_utils.pyインポート用
sys.path.append(os.path.join(
    os.path.dirname(os.path.abspath(__file__)),
    os.path.pardir))

from debpkg_utils import *

import manualctrl


PACKAGE = "cloudsync"
SERVICE = "nasdsync"
REMOVE_LIST = [
    "/mnt/data/conf/dropbox",
    "/mnt/data/conf/amazons3",
    "/mnt/data/conf/azure",
    "/mnt/data/conf/box",
    "/mnt/data/conf/onedrive",
    "/mnt/data/conf/onedrive_business",
    "/mnt/sataraid1/dropbox_tmp",
    "/mnt/sataraid1/nasdsync_download_tmp",]



class ShareXmlConfModifier(BaseXmlConfModifier):

    FAL = FAL_SHARES_PATH

    class ShareServiceModifyInfo():
        PAR_XPATH = "//shareservice"
        INSTALL_NODE_LIST = [
            XmlConfNode("""<amazons3 enable="false">
                    <accesskey/>
                    <secretkey/>
                    <bucket/>
                    <httpmethod>https</httpmethod>
                    <storageclass>STANDARD</storageclass>
                    <downloadinterval>3600</downloadinterval>
                    <endpoint/>
                </amazons3>"""),
            XmlConfNode("<dropbox enable='false'/>"),
            XmlConfNode("""<azure enable="false">
                    <accountname/>
                    <accesskey/>
                    <container/>
                    <httpmethod>https</httpmethod>
                    <downloadinterval>3600</downloadinterval>
                </azure>"""),
            XmlConfNode("""<box enable="false">
                    <mailaddress/>
                    <passwd/>
                    <uploadmaxfilesize>250</uploadmaxfilesize>
                    <downloadinterval>3600</downloadinterval>
                </box>""")]
        REMOVE_XPATH_LIST = ["amazons3", "dropbox", "azure", "box",
                                "onedrive", "onedrivebusiness"]
        UPGRADE_NODE_LIST = INSTALL_NODE_LIST

    class AmazonS3ModifyInfo():
        PAR_XPATH = "//shareservice/amazons3"
        INSTALL_NODE_LIST = [
            XmlConfNode("<port/>"),
            XmlConfNode("<uploadmaxfilesize>10240</uploadmaxfilesize>"),
            XmlConfNode("<mpupload enable='true'/>")]
        REMOVE_XPATH_LIST = []
        UPGRADE_NODE_LIST = INSTALL_NODE_LIST

    MODIFY_INFO_LIST = [ShareServiceModifyInfo, AmazonS3ModifyInfo]


class ServiceXmlConfModifier(BaseXmlConfModifier):

    FAL = FAL_SERVICECTRL_PATH

    class ShareListModifyInfo():
        PAR_XPATH = "//servicectrl/servicelist"
        INSTALL_NODE_LIST = [
            XmlConfNode("<service enable='true'><name>%s</name></service>" % SERVICE)]
        REMOVE_XPATH_LIST = ["service[name='%s']" % SERVICE]

    class CategoryShareListModifyInfo():
        PAR_XPATH = "//category[name='disk' or name='share' or name='network']/servicelist"
        INSTALL_NODE_LIST = [
            XmlConfNode("<service><name>%s</name></service>" % SERVICE)]
        REMOVE_XPATH_LIST = ["service[name='%s']" % SERVICE]
       
    MODIFY_INFO_LIST = [ShareListModifyInfo, CategoryShareListModifyInfo]


if __name__ == "__main__":
    share_ins = ShareXmlConfModifier()
    service_ins = ServiceXmlConfModifier()
    if sys.argv[1] == "postinst_configure_install":
        share_ins.install()
        service_ins.install()
        msg_xml_modify_with_file(PACKAGE)
        valid_xml_modify_with_file(PACKAGE)
        manualctrl.install()
        service_start(SERVICE, is_check_mounted=True)

    elif sys.argv[1] == "postinst_configure_upgrade":
        # ここで既存の設定に対しての処理をする
        share_ins.upgrade()
        msg_xml_modify_with_file(PACKAGE)
        valid_xml_modify_with_file(PACKAGE)
        manualctrl.update()
        service_start(SERVICE)

    elif sys.argv[1] == "prerm_remove":
        share_ins.remove()
        service_ins.remove()
        service_stop(SERVICE)
        remove_files(REMOVE_LIST)
        manualctrl.uninstall()

    elif sys.argv[1] == "prerm_upgrade":
        # upgrade時は既存の設定を削除しない
        service_stop(SERVICE)
