#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta


import libevh.evhcmd as evhcmd
from ionas.request import Entry
from fal_info import FAL_SERVICECTRL_PATH
from product_conf.reqinfo import (Results, ReqTypes)
from product_conf import STOR_IF_TO_VOL

ACTION_PATH = "eventinfo/@action"
VOL_NAME_PATH = "eventinfo/volume/name"

SERVICE_XML = "<servicectrl><servicelist><service><name>%s</name>" + \
            "</service></servicelist></servicectrl>"


class EventHnadler(evhcmd.EvhCmd):

    def __is_internal_vol_event(self, vol_name):

        if vol_name != STOR_IF_TO_VOL["internal"][1]:
            return False
        return True

    def __start_or_stop_service(self, type, service_name="nasdsync"):
        entry = Entry(type, SERVICE_XML % service_name)
        self.send_entry(entry, FAL_SERVICECTRL_PATH)

    #
    # Request handlers
    #

    def __event_handler(self, entry):
        """Handle "event" request."""

        body = entry.get()

        action = body.get_value(ACTION_PATH)
        vol_name = body.get_value(VOL_NAME_PATH)

        if self.__is_internal_vol_event(vol_name):
            if action == "mount":
                self.__start_or_stop_service(ReqTypes.START)
            elif action == "unmount":
                self.__start_or_stop_service(ReqTypes.STOP)

        entry.set_result(Results.OK)
        return entry

    def __init__(self, option=None):
        """Constructor."""

        evhcmd.EvhCmd.__init__(self, option=option)

        self.set_handler(ReqTypes.EVENT, self.__event_handler)

#
# Main
#

if __name__ == "__main__":
    EventHnadler(option=evhcmd.EvhCmdOption()).handle_request()
