#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""FAL command for handling Shares Ctrl event"""

from ionas.request import Entry
from iobase.exception import ExecError
import libevh.evhcmd as evhcmd
from fal_info import FAL_SERVICECTRL_PATH
from product_conf.reqinfo import Results, ReqTypes
from libevh.util import fal_volctrl_query


SERVICE_ENTRY = "<servicectrl><servicelist><service><name>%s</name>" + \
            "</service></servicelist></servicectrl>"


class EvhSharesCtrl(evhcmd.EvhCmd):
    """Shares Ctrl Event Handler command implementation class."""

    def __is_vfsext(default=True):
        try:
            cur_status = fal_volctrl_query("sataraid1")

            if cur_status.get_value("volume/filesystem") == "vfsext":
                return True
            return False

        except:
            return default

    def __start_or_stop_service(self, type, service_name):
        entry = Entry(type, SERVICE_ENTRY % service_name)
        response = self.send_entry(entry, FAL_SERVICECTRL_PATH)
        return response

    #
    # Request handlers
    #

    def __event_handler(self, entry):
        """Handle "event" request."""

        if not self.__is_vfsext():
            entry.set_result(Results.OK)
            return entry

        res_entry = self.__start_or_stop_service(ReqTypes.SUSPEND, "nasdsync")

        if res_entry.get_result() != Results.OK:
            raise ExecError(FAL_SERVICECTRL_PATH)

        entry.set_result(Results.OK)
        return entry

    def __init__(self):
        """Constructor."""

        evhcmd.EvhCmd.__init__(self, evhcmd.EvhCmdOption())

        self.set_handler(ReqTypes.EVENT, self.__event_handler)

#
# Main
#

if __name__ == "__main__":
    EvhSharesCtrl().handle_request()
