#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""FAL command for handling Shares Ctrl event"""

from ionas.request import Entry
from iobase.exception import ExecError
import libevh.evhcmd as evhcmd
import pal_info
from product_conf.reqinfo import Results, ReqTypes

from subprocess import Popen, PIPE
from product_conf import SUDO_CMD


MANAGER_PATH = '/usr/local/bin/dropbox_access_token_manager_for_nasdsync'

SHARES_PATH = "eventinfo/shares"


class EvhSharesCtrl(evhcmd.EvhCmd):
    """Shares Ctrl Event Handler command implementation class."""

    #
    # Request handlers
    #

    def __event_handler(self, entry):
        """Handle "event" request."""

        # res_entry = self.send_entry(
        #     Entry(ReqTypes.CLEAR, entry.get().get_node(SHARES_PATH)),
        #     pal_info.PAL_DROPBOX_PATH)
        # if res_entry.get_result() != Results.OK:
        #     raise ExecError(pal_info.PAL_DROPBOX_PATH)
        for share_node in entry.get().get_node_list('eventinfo/shares/share'):
            sharename = share_node.get_value('name')
            if sharename:
                command = [SUDO_CMD, MANAGER_PATH, '--revoke-access-token', sharename]
                process = Popen(command, stdout=PIPE)
                output, error = process.communicate()

        entry.set_result(Results.OK)
        return entry

    def __init__(self):
        """Constructor."""

        evhcmd.EvhCmd.__init__(self, evhcmd.EvhCmdOption())

        self.set_handler(ReqTypes.EVENT, self.__event_handler)

#
# Main
#

if __name__ == "__main__":
    EvhSharesCtrl().handle_request()
