#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""FAL command for handling Shares Ctrl event"""

from ionas.request import Entry
from iobase.exception import ExecError, NotFoundError
import libevh.evhcmd as evhcmd
import pal_info
from product_conf.reqinfo import Results, ReqTypes


SHARES_PATH = "eventinfo/shares"
DROPBOX_PATH = SHARES_PATH + "/share/shareservice/dropbox"


class EvhSharesCtrl(evhcmd.EvhCmd):
    """Shares Ctrl Event Handler command implementation class."""

    #
    # Utility method
    #

    def __is_dropbox_enabled(self, entry):
        
        try:
            if entry.get().get_node(DROPBOX_PATH).is_enabled():
                return True
            return False
        except NotFoundError:
            return False

    #
    # Request handlers
    #

    def __event_handler(self, entry):
        """Handle "event" request."""

        # if self.__is_dropbox_enabled(entry):
        #     entry.set_result(Results.OK)
        #     return entry

        # res_entry = self.send_entry(
        #     Entry(ReqTypes.CLEAR, entry.get().get_node(SHARES_PATH)),
        #     pal_info.PAL_DROPBOX_PATH)
        # if res_entry.get_result() != Results.OK:
        #     raise ExecError(pal_info.PAL_DROPBOX_PATH)

        entry.set_result(Results.OK)
        return entry

    def __init__(self):
        """Constructor."""

        evhcmd.EvhCmd.__init__(self, evhcmd.EvhCmdOption())

        self.set_handler(ReqTypes.EVENT, self.__event_handler)

#
# Main
#

if __name__ == "__main__":
    EvhSharesCtrl().handle_request()
