# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Module to access the Box server with REST API."""


try:
    from cloudsync.box.client import (FileClient,)
except:
    from ionas.restapi.client import (FileClient,)
from cloudsync.boxinfo import (ITEM_LIMIT,)


class BoxClient(FileClient):
    """Client class for the Box."""

    def __init__(self, box_info, headers={}, proxies=None):
        """Constructor."""

        FileClient.__init__(self, box_info, headers, proxies)

    def list_contents(self, path, headers={}):
        """Return a list of contents in "path" directory."""

        self._prepare_path(path, self.access_info.Purpose.ACCESS_DIRECTORY)
        offset = 0
        content_list = []
        while True:
            request_info = self.access_info.get_list_contents_req_info(path,
                                            offset=offset,
                                            limit=ITEM_LIMIT)
            response = self._urlopen(request_info, headers)
            content_part_list = self.access_info.to_content_list(response)
            if not len(content_part_list):
                break;
            offset += ITEM_LIMIT
            content_list += content_part_list
        return content_list
