# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

from onedrivesdk import AuthProvider
from onedrivesdk .options import *


def authenticate_request_(self, request):
    """Append the required authentication headers
    to the specified request. This will only function
    if a session has been successfully created using
    :func:`authenticate`. This will also refresh the
    authentication token if necessary.

    Args:
        request (:class:`RequestBase<onedrivesdk.request_base.RequestBase>`):
            The request to authenticate
    """
    if self._session is None:
        raise RuntimeError("""Session must be authenticated 
            before applying authentication to a request.""")

    if self._session.is_expired() \
            and len(set(self.scopes).
                            intersection(set(['wl.offline_access', 'offline_access']))) > 0:
        self.refresh_token()

    request.append_option(
        HeaderOption("Authorization",
                     "bearer {0}".format(self._session.access_token)))

AuthProvider.authenticate_request = authenticate_request_
