# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from command import Command
from iobase.xmldata import XmlConfNode
from ionas.request import Entry
from fal_info import Results


_empty = object()


class FALOneDrive(Command):

    try:
        from fal_info import FAL_ONEDRIVE_PATH as COMMAND
    except:
        COMMAND_NAME = 'fal_onedrive.py'

    def get_authorize_url_for_nasdsync(self, business=False, default=_empty):
        try:
            url = self._call_get(business=business)['url']
            if url:
                return url
            return default
        except:
            if default is _empty:
                raise
            return default

    def apply(self, sharename, code, business=False):
        try:
            return self._call_apply(sharename, code, business=business)
        except:
            return {}

    def query(self, sharename, business=False):
        try:
            return self._call_query(sharename, business=business)
        except:
            return {}

    def get(self, business=False):
        try:
            return self._call_get(business=business)
        except:
            return {}

    def download(self, sharename):
        try:
            return self._call_download(sharename)
        except:
            return False

    def _call_get(self, business=False):
        entry = Entry('get', '<onedirve />')
        if business:
            option_node = XmlConfNode('<option />')
            option_node.set_bool_attr('forbusiness', True)
            entry.get().append_child(option_node)
        entry = self.request(entry)

        onedrive_node = entry.get()
        url = onedrive_node.get_value('url', None)

        return {
            'url': url,
        }

    def _call_apply(self, sharename, code, business=False):
        entry = Entry('apply', '<onedrive><share><name/></share><code/></onedrive>')
        entry.get().get_node('share/name').set_text(sharename)
        entry.get().get_node('code').set_text(code)
        if business:
            option_node = XmlConfNode('<option />')
            option_node.set_bool_attr('forbusiness', True)
            entry.get().append_child(option_node)
        entry = self.request(entry)

        result = entry.get_result()

        if business:
            constname, arglist = {
                Results.OK: [None, {}],  # TODO
                Results.AUTH_ERROR: ['ERR_ONEDRIVEB_AUTH', {'name': sharename}],
                Results.CONNECT_ERROR: ['ERR_ONEDRIVEB_CONNECT', {'name': sharename}],
            }.get(result, ['ERR_ONEDRIVEB_AUTH', {'name': sharename}])
        else:
            constname, arglist = {
                Results.OK: [None, {}],  # TODO
                Results.AUTH_ERROR: ['ERR_ONEDRIVE_AUTH', {'name': sharename}],
                Results.CONNECT_ERROR: ['ERR_ONEDRIVE_CONNECT', {'name': sharename}],
            }.get(result, ['ERR_ONEDRIVE_AUTH', {'name': sharename}])
        self._set_message(constname, arglist=arglist)

        return result in [Results.OK]

    def _call_query(self, sharename, business=False):
        entry = Entry('query', '<onedrive><share><name/></share></onedrive>')
        entry.get().get_node('share/name').set_text(sharename)
        if business:
            option_node = XmlConfNode('<option />')
            option_node.set_bool_attr('forbusiness', True)
            entry.get().append_child(option_node)
        entry = self.request(entry)

        result = entry.get_result()
        token = entry.get().get_value('token', '')

        return {
            'token': token,
        }

    def _call_download(self, sharename):
        entry = Entry("download", """<download/>""")
        entry.get().append_child("sharename", text=sharename)
        entry = self.request(entry)

        result = getattr(entry, "get_result", lambda: None)()

        return result in [Results.OK]


if __name__ == '__main__':
    pass
