# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from django.utils.translation import ugettext as _
from django.utils import simplejson
from django.http import HttpResponse
from django import forms
from project.view import FuncView, RootView
from project.forms.fields.text import TextField
from project.forms.fields.password import PasswordField
#from project.forms.fields.extras.share import ShareNameField
from project.forms.fields.extras.share import SelectShareField
from project.fal.box import FALBox


class CheckForm(forms.Form):

    box_email = TextField(label=_(u"Box Email"),
                          initial="",
                          required=False,
                          max_length=256)
    box_passwd = PasswordField(label=_(u"Box Password"),
                               initial="",
                               required=False,
                               max_length=256)


class CheckView(RootView):

    default_messages = {
        "Success": _(u"BoxSync: Check Success"),
        "Failed": _(u"BoxSync: Check Failed"),
        "TimeOut": u"%s(%s)" % (_(u"BoxSync: Check Failed"), _(u"BoxSync: Check has timed out.")),
        "LoginFailed": u"%s(%s)" % (_(u"BoxSync: Check Failed"), _(u"BoxSync: Failed to login.")),
    }

    def view(self, request):
        form = CheckForm(data=request.GET)
        result = None
        if form.is_valid():
            result = FALBox().check(form.cleaned_data["box_email"],
                                    form.cleaned_data["box_passwd"])
        message = self.default_messages.get(result, _(u"BoxSync: Check Failed"))
        response = HttpResponse(simplejson.dumps({
                                    "message": message,
                                }),
                                mimetype="application/json;charset=UTF-8;")
        return {
            self.KEY_RESPONSE: response,
        }


class DownloadForm(forms.Form):

    # FIXME: name == name
    #name = ShareNameField()
    def __init__(self, *args, **kwargs):
        super(DownloadForm, self).__init__(*args, **kwargs)
        self.fields["name"] = SelectShareField()


class DownloadView(RootView):

    def view(self, request):
        form = DownloadForm(data=request.GET)
        result = False
        if form.is_valid():
            result = FALBox().download(form.cleaned_data["name"])
        response = HttpResponse(simplejson.dumps({"result": result}),
                                mimetype="application/json;charset=UTF-8;")
        return {
            self.KEY_RESPONSE: response,
        }
