# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from django.utils.translation import ugettext as _
from project.forms.fields.checkbox import CheckboxField
from project.forms.fields.text import TextField
from project.forms.fields.radio import RadioField
from project.forms.fields.select import SelectField
from project.forms.fields.extras.validators.fal import FALValidator
from fal_validinfo import (HttpMethod, DownloadInterval)

ACCOUNTNAME_MAX_LENGTH = 255
ACCESSKEY_MAX_LENGTH = 255
CONTAINER_MAX_LENGTH = 63
CONTAINER_MIN_LENGTH = 3


class AccountNameValidator(FALValidator):
    validator = 'NoCheck'
    options = {"max_length": ACCOUNTNAME_MAX_LENGTH}


class AccessKeyValidator(FALValidator):
    validator = 'NoCheck'
    options = {"max_length": ACCESSKEY_MAX_LENGTH}


class ContainerValidator(FALValidator):
    validator = 'NoCheck'
    options = {
        "max_length": CONTAINER_MAX_LENGTH,
        "min_length": CONTAINER_MIN_LENGTH}


fields = {
    'azure': CheckboxField(
        label=_(u'Microsoft Azure Sync'),
        initial=False,
        attrs={"exclusion_cloud": True}),
    'azure_account_name': TextField(
        label=_(u'Account Name'),
        initial="",
        required=False,
        validators=[AccountNameValidator()],
        max_length=ACCOUNTNAME_MAX_LENGTH),
    'azure_access_key': TextField(
        label=_(u'Access Key'),
        initial="",
        required=False,
        validators=[AccessKeyValidator()],
        max_length=ACCESSKEY_MAX_LENGTH),
    'azure_container': TextField(
        label=_(u'Container Name'),
        initial="",
        required=False,
        validators=[ContainerValidator()],
        max_length=CONTAINER_MAX_LENGTH),
    'azure_protocol': RadioField(
        label=_(u'Protocol'),
        initial=HttpMethod.INITIAL,
        choices=HttpMethod.CHOICES),
    'azure_check_interval': SelectField(
        label=_(u'Check Interval'),
        initial=DownloadInterval.INITIAL,
        choices=DownloadInterval.CHOICES),
}
