# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from django.utils.translation import ugettext as _
from project.forms.fields.checkbox import CheckboxField
from project.forms.fields.text import TextField
from project.forms.fields.radio import RadioField
from project.forms.fields.select import SelectField
from project.forms.fields.extras.validators.fal import FALValidator
from fal_validinfo import (Numeric, RemotePortNumber, HttpMethod, 
    AmazonS3StorageClass, DownloadInterval)

ACCESSKEY_MAX_LENGTH = 255
SECRETKEY_MAX_LENGTH = 255
BUCKET_MAX_LENGTH = 63
BUCKET_MIN_LENGTH = 3
ENDPOINT_MAX_LENGTH = 255
UPLOAD_MAX_FILE_SIZE = 5 * 1024 * 1024
INITIAL_UPLOAD_MAX_FILE_SIZE = 10 * 1024


class AccessKeyValidator(FALValidator):
    validator = 'NoCheck'
    options = {"max_length": ACCESSKEY_MAX_LENGTH}


class SecretKeyValidator(FALValidator):
    validator = 'NoCheck'
    options = {"max_length": SECRETKEY_MAX_LENGTH}


class BucketValidator(FALValidator):
    validator = 'NoCheck'
    options = {
        "max_length": BUCKET_MAX_LENGTH,
        "min_length": BUCKET_MIN_LENGTH}


class EndPointValidator(FALValidator):
    validator = 'NoCheck'
    options = {"max_length": ENDPOINT_MAX_LENGTH}


class PortValidator(FALValidator):
    validator = RemotePortNumber.VALIDATOR
    options = {}


class UploadMaxFileSizeValidator(FALValidator):
    validator = Numeric.VALIDATOR
    options = {"max": UPLOAD_MAX_FILE_SIZE}


fields = {
    'cloudn': CheckboxField(
        label=_(u'Cloudn Sync'),
        initial=False,
        attrs={"exclusion_cloud": True}),
    'cloudn_access_key': TextField(
        label=_(u'Access Key'),
        initial="",
        required=False,
        validators=[AccessKeyValidator()],
        max_length=ACCESSKEY_MAX_LENGTH),
    'cloudn_secret_key': TextField(
        label=_(u'Secret Key'),
        initial="",
        required=False,
        validators=[SecretKeyValidator()],
        max_length=SECRETKEY_MAX_LENGTH),
    'cloudn_bucket': TextField(
        label=_(u'Bucket Name'),
        initial="",
        required=False,
        validators=[BucketValidator()],
        max_length=BUCKET_MAX_LENGTH),
    'cloudn_protocol': RadioField(
        label=_(u'Protocol'),
        initial=HttpMethod.INITIAL,
        choices=HttpMethod.CHOICES),
    'cloudn_storage_class': RadioField(
        label=_(u'Storage Class'),
        initial=AmazonS3StorageClass.INITIAL,
        choices=AmazonS3StorageClass.CHOICES),
    'cloudn_check_interval': SelectField(
        label=_(u'Check Interval'),
        initial=DownloadInterval.INITIAL,
        choices=DownloadInterval.CHOICES),
    'cloudn_end_point': TextField(
        label=_(u'End Point'),
        initial="str.cloudn-service.com",
        required=False,
        validators=[EndPointValidator()],
        max_length=ENDPOINT_MAX_LENGTH),
    'cloudn_port': TextField(
        label=_(u'Port'),
        initial="",
        required=False,
        validators=[PortValidator()]),
    'cloudn_upload_max_file_size': TextField(
        label=_(u'Upload Max File Size'),
        initial=INITIAL_UPLOAD_MAX_FILE_SIZE,
        required=False,
        validators=[UploadMaxFileSizeValidator()]),
    'cloudn_mpupload': CheckboxField(
        label=_(u'Multipart Upload'),
        initial=True),
}
