#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from ..utils import BaseMeans

ENABLE_PATH = "shareservice/amazons3/@enable"
S3_PATH = "shareservice/amazons3/@amazons3"
CLOUDN_PATH = "shareservice/amazons3/@cloudn"


class AmazonS3Means(BaseMeans):
    def _is_enable_path(self, node, path):
        return {'true': True, 'false': False}.get(
            node.get_value(path, None), False)

    def _is_s3_enable(self, node):
        return self._is_enable_path(node, S3_PATH)

    def _is_cloudn_enable(self, node):
        return self._is_enable_path(node, CLOUDN_PATH)

    def get(self, node, path=""):
        """
        パッケージ1.00から1.10への更新時に
        amazons3タグのenable=trueで
        amazons3属性がない場合も
        考慮している
        """
        if self._is_cloudn_enable(node):
            return self.DEFAULT
        elif self._is_enable_path(node, ENABLE_PATH):
            return super(AmazonS3Means, self).get(node, path)
        return self.DEFAULT


class AmazonS3(AmazonS3Means):
    PATH = "shareservice/amazons3/@amazons3"

    def _is_enable(self, node):
        return {'true': True, 'false': False}.get(
            node.get_value(ENABLE_PATH, None), False)

    def get(self, node, path=""):
        if self._is_cloudn_enable(node):
            return False
        elif self._is_enable(node):
            return True
        return False 

    def set(self, node, val, path=""):
        super(AmazonS3, self).set(node, val, path)
        if val:
            # 有効の場合は@enableも有効化
            self._set_attr(node, val, ENABLE_PATH)
        else:
            # 無効の場合は@cloudnも無効なら@enableを無効化
            if not self._is_cloudn_enable(node):
                self._set_attr(node, val, ENABLE_PATH)


class AccessKey(AmazonS3Means):
    PATH = "shareservice/amazons3/accesskey"
    IS_BOOL = False
    DEFAULT = ""


class SecretKey(AmazonS3Means):
    PATH = "shareservice/amazons3/secretkey"
    IS_BOOL = False
    DEFAULT = ""


class Bucket(AmazonS3Means):
    PATH = "shareservice/amazons3/bucket"
    IS_BOOL = False
    DEFAULT = ""


class Protocol(AmazonS3Means):
    PATH = "shareservice/amazons3/httpmethod"
    IS_BOOL = False
    DEFAULT = "https"


class StorageClass(AmazonS3Means):
    PATH = "shareservice/amazons3/storageclass"
    IS_BOOL = False
    DEFAULT = "STANDARD"


class CheckInterval(AmazonS3Means):
    PATH = "shareservice/amazons3/downloadinterval"
    IS_BOOL = False
    DEFAULT = "3600"


class EndPoint(AmazonS3Means):
    PATH = "shareservice/amazons3/endpoint"
    IS_BOOL = False
    DEFAULT = ""


class Port(AmazonS3Means):
    PATH = "shareservice/amazons3/port"
    IS_BOOL = False
    DEFAULT = ""


class UploadMaxFileSize(AmazonS3Means):
    PATH = "shareservice/amazons3/uploadmaxfilesize"
    IS_BOOL = False
    DEFAULT = str(10 * 1024)


class MpUpload(AmazonS3Means):
    PATH = "shareservice/amazons3/mpupload/@enable"
    DEFAULT = True


means = {
    "amazons3": AmazonS3(),
    "amazons3_access_key": AccessKey(),
    "amazons3_secret_key": SecretKey(),
    "amazons3_bucket": Bucket(),
    "amazons3_protocol": Protocol(),
    "amazons3_storage_class": StorageClass(),
    "amazons3_check_interval": CheckInterval(),
    "amazons3_end_point": EndPoint(),
    "amazons3_port": Port(),
    "amazons3_upload_max_file_size": UploadMaxFileSize(),
    "amazons3_mpupload": MpUpload()}
