#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from ..utils import BaseMeans


ENABLE_PATH = "shareservice/amazons3/@enable"
S3_PATH = "shareservice/amazons3/@amazons3"
CLOUDN_PATH = "shareservice/amazons3/@cloudn"


class CloudnMeans(BaseMeans):
    def _is_enable_path(self, node, path):
        return {'true': True, 'false': False}.get(
            node.get_value(path, None), False)

    def _is_s3_enable(self, node):
        return self._is_enable_path(node, S3_PATH)

    def _is_cloudn_enable(self, node):
        return self._is_enable_path(node, CLOUDN_PATH)

    def get(self, node, path=""):
        if not self._is_cloudn_enable(node):
            return self.DEFAULT
        return super(CloudnMeans, self).get(node, path)

    def set(self, node, val, path=""):
        pass


class Cloudn(CloudnMeans):
    PATH = CLOUDN_PATH 

    def set(self, node, val, path=""):
        self._set_attr(node, val, self.PATH)
        if val:
            # 有効の場合は@enableも有効化
            self._set_attr(node, val, ENABLE_PATH)
        else:
            # 無効の場合は@amazons3も無効なら@enableを無効化
            if not self._is_s3_enable(node):
                self._set_attr(node, val, ENABLE_PATH)


class AccessKey(CloudnMeans):
    PATH = "shareservice/amazons3/accesskey"
    IS_BOOL = False
    DEFAULT = ""


class SecretKey(CloudnMeans):
    PATH = "shareservice/amazons3/secretkey"
    IS_BOOL = False
    DEFAULT = ""


class Bucket(CloudnMeans):
    PATH = "shareservice/amazons3/bucket"
    IS_BOOL = False
    DEFAULT = ""


class Protocol(CloudnMeans):
    PATH = "shareservice/amazons3/httpmethod"
    IS_BOOL = False
    DEFAULT = "https"


class StorageClass(CloudnMeans):
    PATH = "shareservice/amazons3/storageclass"
    IS_BOOL = False
    DEFAULT = "STANDARD"


class CheckInterval(CloudnMeans):
    PATH = "shareservice/amazons3/downloadinterval"
    IS_BOOL = False
    DEFAULT = "3600"


class EndPoint(CloudnMeans):
    PATH = "shareservice/amazons3/endpoint"
    IS_BOOL = False
    DEFAULT = "str.cloudn-service.com"


class Port(CloudnMeans):
    PATH = "shareservice/amazons3/port"
    IS_BOOL = False
    DEFAULT = ""


class UploadMaxFileSize(CloudnMeans):
    PATH = "shareservice/amazons3/uploadmaxfilesize"
    IS_BOOL = False
    DEFAULT = str(10 * 1024)


class MpUpload(CloudnMeans):
    PATH = "shareservice/amazons3/mpupload/@enable"
    DEFAULT = True


means = {
    "cloudn": Cloudn(),
    "cloudn_access_key": AccessKey(),
    "cloudn_secret_key": SecretKey(),
    "cloudn_bucket": Bucket(),
    "cloudn_protocol": Protocol(),
    "cloudn_storage_class": StorageClass(),
    "cloudn_check_interval": CheckInterval(),
    "cloudn_end_point": EndPoint(),
    "cloudn_port": Port(),
    "cloudn_upload_max_file_size": UploadMaxFileSize(),
    "cloudn_mpupload": MpUpload()}
