#:!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from subprocess import Popen, PIPE

from product_conf import SUDO_CMD


MANAGER_PATH = '/usr/local/bin/dropbox_access_token_manager_for_nasdsync'


def _obtain_access_token(code):
    command = [SUDO_CMD, MANAGER_PATH, '--obtain-access-token', '--', code]
    process = Popen(command, stdout=PIPE)
    output, error = process.communicate()

    access_token = output.strip()
    return access_token

def _revoke_access_token(sharename):
    command = [SUDO_CMD, MANAGER_PATH, '--revoke-access-token', sharename]
    process = Popen(command, stdout=PIPE)
    output, error = process.communicate()

def _save_access_token(sharename, access_token):
    command = [SUDO_CMD, MANAGER_PATH, '--save-access-token', '--', sharename, access_token]
    process = Popen(command, stdout=PIPE)
    output, error = process.communicate()

def _load_access_token(sharename):
    command = [SUDO_CMD, MANAGER_PATH, '--load-access-token', sharename]
    process = Popen(command, stdout=PIPE)
    output, error = process.communicate()

    access_token = output.strip()
    return access_token


class Dropbox(object):

    def rule(self, data, err_cls, _):
        sharename = data.get('name')
        dropbox_enabled = data.get('dropbox_enabled')
        dropbox_code = data.get('dropbox_code')
        revoke_flag = data.get('dropbox_revoke_access_token_flag')
        if dropbox_enabled:
            if dropbox_code:
                dropbox_access_token = _load_access_token(sharename)
                if dropbox_access_token:
                    _revoke_access_token(sharename)
                    if _load_access_token(sharename):
                        # raise err_cls('FIXME: can not revoke access_token')
                        raise err_cls(_(u'dropbox: can not revoke access_token'))
                dropbox_access_token = _obtain_access_token(dropbox_code)
                if dropbox_access_token:
                    _save_access_token(sharename, dropbox_access_token)
            if _load_access_token(sharename):
                pass
            else:
                # raise err_cls('FIXME: can not access to dropbox')
                raise err_cls(_(u'dropbox: can not access to dropbox'))
        else:
            if revoke_flag:
                _revoke_access_token(sharename)
                if _load_access_token(sharename):
                    # raise err_cls('FIXME: can not revoke access_token')
                    raise err_cls(_(u'dropbox: can not revoke access_token'))


rules = {
    "dropbox": Dropbox(),
}
